from .dataset import *
from .pgplot import *
from .plotutils import *
from ._version import __version__


# Easy access to color palettes
DEEP = color_palette('deep')
MUTED = color_palette('muted')
PASTEL = color_palette('pastel')
BRIGHT = color_palette('bright')
DARK = color_palette('dark')
COLORBLIND = color_palette('colorblind')
